==> jc-1.4.0.tar.gz: org/ietf/jgss/GSSException.h <==
// public class org.ietf.jgss.GSSException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d82ad86895ee19c6 org_ietf_jgss_GSSException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_org_ietf_jgss_GSSException_H_
#define _JC_org_ietf_jgss_GSSException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ResourceBundle$object;

// Typedefs
typedef struct _jc_org_ietf_jgss_GSSException$sub_refs	_jc_org_ietf_jgss_GSSException$sub_refs;
typedef struct _jc_org_ietf_jgss_GSSException$sub_nonrefs	_jc_org_ietf_jgss_GSSException$sub_nonrefs;
typedef struct _jc_org_ietf_jgss_GSSException$refs	_jc_org_ietf_jgss_GSSException$refs;
typedef struct _jc_org_ietf_jgss_GSSException$nonrefs	_jc_org_ietf_jgss_GSSException$nonrefs;
typedef struct _jc_org_ietf_jgss_GSSException$object	_jc_org_ietf_jgss_GSSException$object;

typedef struct _jc_org_ietf_jgss_GSSException$fields_struct	_jc_org_ietf_jgss_GSSException$fields_struct;
typedef const struct _jc_org_ietf_jgss_GSSException$vmethods	_jc_org_ietf_jgss_GSSException$vmethods;
typedef const struct _jc_org_ietf_jgss_GSSException$vtable	_jc_org_ietf_jgss_GSSException$vtable;
typedef const struct _jc_org_ietf_jgss_GSSException$vtype	_jc_org_ietf_jgss_GSSException$vtype;

// Class fields structure
struct _jc_org_ietf_jgss_GSSException$fields_struct {
	struct _jc_java_lang_Class$object	*class__24org__24ietf__24jgss__24GSSException;
	jlong	serialVersionUID;
	jint	BAD__5fBINDINGS;
	jint	BAD__5fMECH;
	jint	BAD__5fMIC;
	jint	BAD__5fNAME;
	jint	BAD__5fNAMETYPE;
	jint	BAD__5fQOP;
	jint	BAD__5fSTATUS;
	jint	CONTEXT__5fEXPIRED;
	jint	CREDENTIALS__5fEXPIRED;
	jint	DEFECTIVE__5fCREDENTIAL;
	jint	DEFECTIVE__5fTOKEN;
	jint	DUPLICATE__5fELEMENT;
	jint	DUPLICATE__5fTOKEN;
	jint	FAILURE;
	jint	GAP__5fTOKEN;
	jint	NAME__5fNOT__5fMN;
	jint	NO__5fCONTEXT;
	jint	NO__5fCRED;
	jint	OLD__5fTOKEN;
	jint	UNAUTHORIZED;
	jint	UNAVAILABLE;
	jint	UNSEQ__5fTOKEN;
};
extern _jc_org_ietf_jgss_GSSException$fields_struct _jc_org_ietf_jgss_GSSException$class_fields;

// Constructors
extern void _jc_org_ietf_jgss_GSSException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint);
extern void _jc_org_ietf_jgss_GSSException$method$_init$161f97cd57dfa523(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_org_ietf_jgss_GSSException$method$getMajor$36fffb9e2afa548e(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMajorString$4e6033aad3cd0017(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
extern jint _jc_org_ietf_jgss_GSSException$method$getMinor$243ff56adf208cf7(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMinorString$e929676fbb396775(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMsg$60df58b7d35a1e59(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_ietf_jgss_GSSException$method$setMinor$b903bc72e0fb2b9a(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);

// Virtual method descriptors
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMajor$36fffb9e2afa548e;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMajorString$4e6033aad3cd0017;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMinor$243ff56adf208cf7;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMinorString$e929676fbb396775;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMsg$60df58b7d35a1e59;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$setMinor$b903bc72e0fb2b9a;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_ietf_jgss_GSSException$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_org_ietf_jgss_GSSException$vmethods {
	jint	(*getMajor$36fffb9e2afa548e)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
	struct _jc_java_lang_String$object	*(*getMajorString$4e6033aad3cd0017)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
	jint	(*getMinor$243ff56adf208cf7)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
	struct _jc_java_lang_String$object	*(*getMinorString$e929676fbb396775)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
	struct _jc_java_lang_String$object	*(*getMsg$60df58b7d35a1e59)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
	void	(*setMinor$b903bc72e0fb2b9a)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *);
};

// Vtable
struct _jc_org_ietf_jgss_GSSException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_ietf_jgss_GSSException$vmethods	org_ietf_jgss_GSSException;
};

// Vtype
struct _jc_org_ietf_jgss_GSSException$vtype {
	_jc_type			type;
	_jc_org_ietf_jgss_GSSException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_ietf_jgss_GSSException$sub_refs {
	struct _jc_java_lang_String$object	*minorString;
	struct _jc_java_util_ResourceBundle$object	*messages;
};

// Reference instance fields (object)
struct _jc_org_ietf_jgss_GSSException$refs {
    _jc_org_ietf_jgss_GSSException$sub_refs	org_ietf_jgss_GSSException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_ietf_jgss_GSSException$sub_nonrefs {
	jint	major;
	jint	minor;
};

// Non-reference instance fields (object)
struct _jc_org_ietf_jgss_GSSException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_ietf_jgss_GSSException$sub_nonrefs	org_ietf_jgss_GSSException;
};

// Object instance structure
struct _jc_org_ietf_jgss_GSSException$object {
	_jc_org_ietf_jgss_GSSException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_ietf_jgss_GSSException$vtype	*vtype;
	_jc_org_ietf_jgss_GSSException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_ietf_jgss_GSSException$vtype _jc_org_ietf_jgss_GSSException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_ietf_jgss_GSSException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_ietf_jgss_GSSException$class_object;

#endif	/* _JC_org_ietf_jgss_GSSException_H_ */

==> jc-1.4.6.tar.gz: org/ietf/jgss/GSSException.h <==
// public class org.ietf.jgss.GSSException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d82ad86895ee19c6 org_ietf_jgss_GSSException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_org_ietf_jgss_GSSException_H_
#define _JC_org_ietf_jgss_GSSException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ResourceBundle$object;

// Typedefs
typedef struct _jc_org_ietf_jgss_GSSException$sub_refs	_jc_org_ietf_jgss_GSSException$sub_refs;
typedef struct _jc_org_ietf_jgss_GSSException$sub_nonrefs	_jc_org_ietf_jgss_GSSException$sub_nonrefs;
typedef struct _jc_org_ietf_jgss_GSSException$refs	_jc_org_ietf_jgss_GSSException$refs;
typedef struct _jc_org_ietf_jgss_GSSException$nonrefs	_jc_org_ietf_jgss_GSSException$nonrefs;
typedef struct _jc_org_ietf_jgss_GSSException$object	_jc_org_ietf_jgss_GSSException$object;

typedef struct _jc_org_ietf_jgss_GSSException$fields_struct	_jc_org_ietf_jgss_GSSException$fields_struct;
typedef const struct _jc_org_ietf_jgss_GSSException$vmethods	_jc_org_ietf_jgss_GSSException$vmethods;
typedef const struct _jc_org_ietf_jgss_GSSException$vtable	_jc_org_ietf_jgss_GSSException$vtable;
typedef const struct _jc_org_ietf_jgss_GSSException$vtype	_jc_org_ietf_jgss_GSSException$vtype;

// Class fields structure
struct _jc_org_ietf_jgss_GSSException$fields_struct {
	struct _jc_java_lang_Class$object	*class__24org__24ietf__24jgss__24GSSException;
	jlong	serialVersionUID;
	jint	BAD__5fBINDINGS;
	jint	BAD__5fMECH;
	jint	BAD__5fMIC;
	jint	BAD__5fNAME;
	jint	BAD__5fNAMETYPE;
	jint	BAD__5fQOP;
	jint	BAD__5fSTATUS;
	jint	CONTEXT__5fEXPIRED;
	jint	CREDENTIALS__5fEXPIRED;
	jint	DEFECTIVE__5fCREDENTIAL;
	jint	DEFECTIVE__5fTOKEN;
	jint	DUPLICATE__5fELEMENT;
	jint	DUPLICATE__5fTOKEN;
	jint	FAILURE;
	jint	GAP__5fTOKEN;
	jint	NAME__5fNOT__5fMN;
	jint	NO__5fCONTEXT;
	jint	NO__5fCRED;
	jint	OLD__5fTOKEN;
	jint	UNAUTHORIZED;
	jint	UNAVAILABLE;
	jint	UNSEQ__5fTOKEN;
};
extern _jc_org_ietf_jgss_GSSException$fields_struct _jc_org_ietf_jgss_GSSException$class_fields;

// Constructors
extern void _jc_org_ietf_jgss_GSSException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint) _JC_JCNI_ATTR;
extern void _jc_org_ietf_jgss_GSSException$method$_init$161f97cd57dfa523(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_ietf_jgss_GSSException$method$getMajor$36fffb9e2afa548e(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMajorString$4e6033aad3cd0017(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
extern jint _jc_org_ietf_jgss_GSSException$method$getMinor$243ff56adf208cf7(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMinorString$e929676fbb396775(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$getMsg$60df58b7d35a1e59(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_ietf_jgss_GSSException$method$setMinor$b903bc72e0fb2b9a(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_ietf_jgss_GSSException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMajor$36fffb9e2afa548e;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMajorString$4e6033aad3cd0017;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMinor$243ff56adf208cf7;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMinorString$e929676fbb396775;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$getMsg$60df58b7d35a1e59;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$setMinor$b903bc72e0fb2b9a;
extern _jc_method _jc_org_ietf_jgss_GSSException$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_ietf_jgss_GSSException$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_ietf_jgss_GSSException$vmethods {
	jint	(*getMajor$36fffb9e2afa548e)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMajorString$4e6033aad3cd0017)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
	jint	(*getMinor$243ff56adf208cf7)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMinorString$e929676fbb396775)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMsg$60df58b7d35a1e59)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setMinor$b903bc72e0fb2b9a)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_ietf_jgss_GSSException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_ietf_jgss_GSSException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_ietf_jgss_GSSException$vmethods	org_ietf_jgss_GSSException;
};

// Vtype
struct _jc_org_ietf_jgss_GSSException$vtype {
	_jc_type			type;
	_jc_org_ietf_jgss_GSSException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_ietf_jgss_GSSException$sub_refs {
	struct _jc_java_lang_String$object	*minorString;
	struct _jc_java_util_ResourceBundle$object	*messages;
};

// Reference instance fields (object)
struct _jc_org_ietf_jgss_GSSException$refs {
    _jc_org_ietf_jgss_GSSException$sub_refs	org_ietf_jgss_GSSException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_ietf_jgss_GSSException$sub_nonrefs {
	jint	major;
	jint	minor;
};

// Non-reference instance fields (object)
struct _jc_org_ietf_jgss_GSSException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_ietf_jgss_GSSException$sub_nonrefs	org_ietf_jgss_GSSException;
};

// Object instance structure
struct _jc_org_ietf_jgss_GSSException$object {
	_jc_org_ietf_jgss_GSSException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_ietf_jgss_GSSException$vtype	*vtype;
	_jc_org_ietf_jgss_GSSException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_ietf_jgss_GSSException$vtype _jc_org_ietf_jgss_GSSException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_ietf_jgss_GSSException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_ietf_jgss_GSSException$class_object;

#endif	/* _JC_org_ietf_jgss_GSSException_H_ */
